==> aws-java-sdk-sns-1.11.29-sources.jar: com/amazonaws/services/sns/model/transform/DeleteTopicResultStaxUnmarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.sns.model.transform;

import java.util.Map;
import java.util.HashMap;
import java.util.ArrayList;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.sns.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * DeleteTopicResult StAX Unmarshaller
 */
public class DeleteTopicResultStaxUnmarshaller implements
        Unmarshaller<DeleteTopicResult, StaxUnmarshallerContext> {

    public DeleteTopicResult unmarshall(StaxUnmarshallerContext context)
            throws Exception {
        DeleteTopicResult deleteTopicResult = new DeleteTopicResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 1;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return deleteTopicResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return deleteTopicResult;
                }
            }
        }
    }

    private static DeleteTopicResultStaxUnmarshaller instance;

    public static DeleteTopicResultStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new DeleteTopicResultStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-sns-1.11.46-sources.jar: com/amazonaws/services/sns/model/transform/DeleteTopicResultStaxUnmarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.sns.model.transform;

import java.util.Map;
import java.util.HashMap;
import java.util.ArrayList;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.sns.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * DeleteTopicResult StAX Unmarshaller
 */
public class DeleteTopicResultStaxUnmarshaller implements Unmarshaller<DeleteTopicResult, StaxUnmarshallerContext> {

    public DeleteTopicResult unmarshall(StaxUnmarshallerContext context) throws Exception {
        DeleteTopicResult deleteTopicResult = new DeleteTopicResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 1;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return deleteTopicResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return deleteTopicResult;
                }
            }
        }
    }

    private static DeleteTopicResultStaxUnmarshaller instance;

    public static DeleteTopicResultStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new DeleteTopicResultStaxUnmarshaller();
        return instance;
    }
}
